@@ -48,6 +48,9 @@ class Storage(hamster.storage.Storage):
         activity = self.fetchone("select name from activities where id = ?", (id, ))
         existing_id = self.__get_activity_by_name(activity['name'], category_id)
         
+        if id == existing_id: # we are already there, go home
+            return False
+        
         if existing_id: #ooh, we have something here!
             # first move all facts that belong to movable activity to the new one
             update = """
@@ -72,6 +75,8 @@ class Storage(hamster.storage.Storage):
             """
             
             self.execute(statement, (category_id, max_order, id))
+        
+        return True
     
     def __add_category(self, name):
         new_rec = self.fetchone("select max(id) +1, max(category_order) + 1  from categories")
@@ -133,8 +138,8 @@ class Storage(hamster.storage.Storage):
                      ORDER BY deleted, id desc
                         LIMIT 1
             """
-            
-            res = self.fetchone(query, (name,))
+
+            res = self.fetchone(query, (name, ))
         
         if res:
             # if the activity was marked as deleted, ressurect on first call
@@ -178,7 +183,7 @@ class Storage(hamster.storage.Storage):
                 LEFT JOIN activities b ON a.activity_id = b.id
                     WHERE a.id = ? 
         """
-        return self.fetchone(query, (id,))
+        return self.fetchone(query, (id, ))
 
     def __get_last_activity(self):
         query = """
@@ -271,7 +276,12 @@ class Storage(hamster.storage.Storage):
         if day_facts:
             last_fact = day_facts[-1]
             
-            if last_fact['end_time'] == None and start_time > last_fact['start_time']:
+            if last_fact['end_time'] == None and last_fact['start_time'] < start_time:
+                #if this is the same, ongoing activity, then there is no need to create another one
+                if last_fact['activity_id'] == activity_id:
+                    return last_fact
+                
+                
                 delta = (start_time - last_fact['start_time'])
             
                 if 60 >= delta.seconds >= 0:
